# Radar Report
### On this page
  * [Overview](https://help.sap.com/docs/leanix/ea/radar-report#overview)
  * [Configuring Rings and Sectors for Fact Sheet Classification](https://help.sap.com/docs/leanix/ea/radar-report#configuring-rings-and-sectors-for-fact-sheet-classification)
  * [Applying Views](https://help.sap.com/docs/leanix/ea/radar-report#applying-views)
  * [Applying Filters](https://help.sap.com/docs/leanix/ea/radar-report#applying-filters)
  * [Side Panel for Additional Information](https://help.sap.com/docs/leanix/ea/radar-report#side-panel-for-additional-information)
  * [Organization-Specific Technology Assessment](https://help.sap.com/docs/leanix/ea/radar-report#organization-specific-technology-assessment)


A Radar report offers a visual representation of fact sheets categorized in rings and sectors. It aids in understanding an organization's tech landscape and evaluate technology standards.
